@@ -1,6 +1,6 @@
 #include "cpucache.h"
 #include "common/sysctl.h"
-#include "util/stringUtils.h"
+#include "common/stringUtils.h"
 
 const char* ffDetectCPUCache(FFCPUCacheResult* result)
 {
@@ -9,7 +9,7 @@ const char* ffDetectCPUCache(FFCPUCacheResult* result)
     if (nPerfLevels <= 0) return "sysctl(hw.nperflevels) failed";
 
     // macOS provides the global system cache line size
-    uint32_t lineSize = (uint32_t) ffSysctlGetInt("hw.cachelinesize", 0);
+    uint32_t lineSize = (uint32_t) ffSysctlGetInt64("hw.cachelinesize", 0);
 
     char sysctlKey[128] = "hw.perflevelN.";
     char* pNum = sysctlKey + strlen("hw.perflevel");
@@ -20,35 +20,35 @@ const char* ffDetectCPUCache(FFCPUCacheResult* result)
     {
         *pNum = (char) ('0' + i);
 
-        ffStrCopyN(pSubkey, "physicalcpu", lenLeft);
+        ffStrCopy(pSubkey, "physicalcpu", lenLeft);
         uint32_t ncpu = (uint32_t) ffSysctlGetInt(sysctlKey, 0);
         if (ncpu <= 0) continue;
 
-        ffStrCopyN(pSubkey, "l1icachesize", lenLeft);
+        ffStrCopy(pSubkey, "l1icachesize", lenLeft);
         uint32_t size = (uint32_t) ffSysctlGetInt(sysctlKey, 0);
         if (size)
             ffCPUCacheAddItem(result, 1, size, lineSize, FF_CPU_CACHE_TYPE_INSTRUCTION)->num = ncpu;
 
-        ffStrCopyN(pSubkey, "l1dcachesize", lenLeft);
+        ffStrCopy(pSubkey, "l1dcachesize", lenLeft);
         size = (uint32_t) ffSysctlGetInt(sysctlKey, 0);
         if (size)
             ffCPUCacheAddItem(result, 1, size, lineSize, FF_CPU_CACHE_TYPE_DATA)->num = ncpu;
 
-        ffStrCopyN(pSubkey, "l2cachesize", lenLeft);
+        ffStrCopy(pSubkey, "l2cachesize", lenLeft);
         size = (uint32_t) ffSysctlGetInt(sysctlKey, 0);
         if (size)
         {
-            ffStrCopyN(pSubkey, "cpusperl2", lenLeft);
+            ffStrCopy(pSubkey, "cpusperl2", lenLeft);
             uint32_t cpuSper = (uint32_t) ffSysctlGetInt(sysctlKey, 0);
             if (cpuSper)
                 ffCPUCacheAddItem(result, 2, size, lineSize, FF_CPU_CACHE_TYPE_UNIFIED)->num = ncpu / cpuSper;
         }
 
-        ffStrCopyN(pSubkey, "l3cachesize", lenLeft);
+        ffStrCopy(pSubkey, "l3cachesize", lenLeft);
         size = (uint32_t) ffSysctlGetInt(sysctlKey, 0);
         if (size)
         {
-            ffStrCopyN(pSubkey, "cpusperl3", lenLeft);
+            ffStrCopy(pSubkey, "cpusperl3", lenLeft);
             uint32_t cpuSper = (uint32_t) ffSysctlGetInt(sysctlKey, 0);
             if (cpuSper)
                 ffCPUCacheAddItem(result, 3, size, lineSize, FF_CPU_CACHE_TYPE_UNIFIED)->num = ncpu / cpuSper;
