@@ -1,9 +1,11 @@
 #pragma once
 
-#include "fastfetch.h"
+#include "option.h"
 
 #define FF_FONT_MODULE_NAME "Font"
 
-void ffPrintFont(FFFontOptions* options);
+bool ffPrintFont(FFFontOptions* options);
 void ffInitFontOptions(FFFontOptions* options);
 void ffDestroyFontOptions(FFFontOptions* options);
+
+extern FFModuleBaseInfo ffFontModuleInfo;
